@@ -13,9 +13,13 @@
 *
 */
 
+#include <sstream>
+#include <mutex>
+#include <regex>
+
 #include "config.h"
 #include "doxygen.h"
-#include "index.h"
+#include "indexlist.h"
 #include "md5.h"
 #include "message.h"
 #include "util.h"
@@ -25,6 +29,7 @@
 #include "dotgraph.h"
 #include "dotnode.h"
 #include "dotfilepatcher.h"
+#include "fileinfo.h"
 
 #define MAP_CMD "cmapx"
 
@@ -35,72 +40,66 @@
 *  are compared with \a md5. If equal FALSE is returned.
 *  The .md5 is created or updated after successful creation of the output file.
 */
-static bool checkMd5Signature(const QCString &baseName,
-                              const QCString &md5)
+static bool sameMd5Signature(const QCString &baseName,
+                             const QCString &md5)
 {
-  QFile f(baseName+".md5");
-  if (f.open(IO_ReadOnly))
+  bool same = false;
+  char md5stored[33];
+  md5stored[0]=0;
+  std::ifstream f(baseName.str()+".md5",std::ifstream::in | std::ifstream::binary);
+  if (f.is_open())
   {
     // read checksum
-    QCString md5stored(33);
-    int bytesRead=f.readBlock(md5stored.rawData(),32);
+    f.read(md5stored,32);
     md5stored[32]='\0';
     // compare checksum
-    if (bytesRead==32 && md5==md5stored)
+    if (!f.fail() && md5==md5stored)
     {
-      // bail out if equal
-      return FALSE;
+      same = true;
     }
+    //printf("sameSignature(%s,%s==%s)=%d\n",qPrint(baseName),md5stored,qPrint(md5),same);
   }
-  f.close();
-  return TRUE;
+  else
+  {
+    //printf("sameSignature(%s) not found\n",qPrint(baseName));
+  }
+  return same;
 }
 
-static bool checkDeliverables(const QCString &file1,
-                              const QCString &file2=QCString())
+static bool deliverablesPresent(const QCString &file1,const QCString &file2)
 {
-  bool file1Ok = TRUE;
-  bool file2Ok = TRUE;
+  bool file1Ok = true;
+  bool file2Ok = true;
   if (!file1.isEmpty())
   {
-    QFileInfo fi(file1);
+    FileInfo fi(file1.str());
     file1Ok = (fi.exists() && fi.size()>0);
   }
   if (!file2.isEmpty())
   {
-    QFileInfo fi(file2);
+    FileInfo fi(file2.str());
     file2Ok = (fi.exists() && fi.size()>0);
   }
   return file1Ok && file2Ok;
 }
 
-static void removeDotGraph(const QCString &dotName)
-{
-  if (Config_getBool(DOT_CLEANUP))
-  {
-    QDir d;
-    d.remove(dotName);
-  }
-}
-
-static bool insertMapFile(FTextStream &out,const QCString &mapFile,
+static bool insertMapFile(TextStream &out,const QCString &mapFile,
                           const QCString &relPath,const QCString &mapLabel)
 {
-  QFileInfo fi(mapFile);
+  FileInfo fi(mapFile.str());
   if (fi.exists() && fi.size()>0) // reuse existing map file
   {
-    QGString tmpstr;
-    FTextStream tmpout(&tmpstr);
-    DotFilePatcher::convertMapFile(tmpout,mapFile,relPath,FALSE);
-    if (!tmpstr.isEmpty())
+    TextStream t;
+    DotFilePatcher::convertMapFile(t,mapFile,relPath,false);
+    if (!t.empty())
     {
-      out << "<map name=\"" << mapLabel << "\" id=\"" << mapLabel << "\">" << endl;
-      out << tmpstr;
-      out << "</map>" << endl;
+      out << "<map name=\"" << mapLabel << "\" id=\"" << mapLabel << "\">\n";
+      out << t.str();
+      out << "</map>\n";
     }
-    return TRUE;
+    return true;
   }
-  return FALSE; // no map file yet, need to generate it
+  return false; // no map file yet, need to generate it
 }
 
 //--------------------------------------------------------------------
@@ -108,35 +107,41 @@ static bool insertMapFile(FTextStream &out,const QCString &mapFile,
 QCString DotGraph::imgName() const
 {
   return m_baseName + ((m_graphFormat == GOF_BITMAP) ?
-                      ("." + getDotImageExtension()) : (Config_getBool(USE_PDFLATEX) ? ".pdf" : ".eps")); 
+                      ("." + getDotImageExtension()) : (Config_getBool(USE_PDFLATEX) ? ".pdf" : ".eps"));
 }
 
+std::mutex g_dotIndexListMutex;
+
 QCString DotGraph::writeGraph(
-        FTextStream& t,           // output stream for the code file (html, ...)
+        TextStream& t,            // output stream for the code file (html, ...)
         GraphOutputFormat gf,     // bitmap(png/svg) or ps(eps/pdf)
         EmbeddedOutputFormat ef,  // html, latex, ...
-        const char* path,         // output folder
-        const char* fileName,     // name of the code file (for code patcher)
-        const char* relPath,      // output folder relative to code file
+        const QCString &path,     // output folder
+        const QCString &fileName, // name of the code file (for code patcher)
+        const QCString &relPath,  // output folder relative to code file
         bool generateImageMap,    // in case of bitmap, shall there be code generated?
         int graphId)              // number of this graph in the current code, used in svg code
 {
   m_graphFormat = gf;
   m_textFormat = ef;
-  m_dir = QDir(path);
+  m_dir = Dir(path.str());
   m_fileName = fileName;
   m_relPath = relPath;
   m_generateImageMap = generateImageMap;
   m_graphId = graphId;
 
-  m_absPath  = QCString(m_dir.absPath().data()) + "/";
+  m_absPath  = m_dir.absPath() + "/";
   m_baseName = getBaseName();
 
   computeTheGraph();
 
   m_regenerate = prepareDotFile();
 
-  if (!m_doNotAddImageToIndex) Doxygen::indexList->addImageFile(imgName());
+  if (!m_doNotAddImageToIndex)
+  {
+    std::lock_guard<std::mutex> lock(g_dotIndexListMutex);
+    Doxygen::indexList->addImageFile(imgName());
+  }
 
   generateCode(t);
 
@@ -147,81 +152,79 @@ bool DotGraph::prepareDotFile()
 {
   if (!m_dir.exists())
   {
-    term("Output dir %s does not exist!\n", m_dir.path().data());
+    term("Output dir %s does not exist!\n", m_dir.path().c_str());
   }
 
-  QCString sigStr(33);
+  char sigStr[33];
   uchar md5_sig[16];
   // calculate md5
-  MD5Buffer((const unsigned char*)m_theGraph.data(), m_theGraph.length(), md5_sig);
+  MD5Buffer(m_theGraph.data(), m_theGraph.length(), md5_sig);
   // convert result to a string
-  MD5SigToString(md5_sig, sigStr.rawData(), 33);
+  MD5SigToString(md5_sig, sigStr);
 
   // already queued files are processed again in case the output format has changed
 
-  if (!checkMd5Signature(absBaseName(), sigStr) &&
-      checkDeliverables(absImgName(),
-                        m_graphFormat == GOF_BITMAP && m_generateImageMap ? absMapName() : QCString()
-                       )
+  if (sameMd5Signature(absBaseName(), sigStr) &&
+      deliverablesPresent(absImgName(),
+                          m_graphFormat == GOF_BITMAP && m_generateImageMap ? absMapName() : QCString()
+                         )
      )
   {
     // all needed files are there
-    removeDotGraph(absDotName());
     return FALSE;
   }
 
   // need to rebuild the image
 
   // write .dot file because image was new or has changed
-  QFile f(absDotName());
-  if (!f.open(IO_WriteOnly))
+  std::ofstream f(absDotName().str(),std::ofstream::out | std::ofstream::binary);
+  if (!f.is_open())
   {
-    err("Could not open file %s for writing\n",f.name().data());
+    err("Could not open file %s for writing\n",qPrint(absDotName()));
     return TRUE;
   }
-  FTextStream t(&f);
-  t << m_theGraph;
+  f << m_theGraph;
   f.close();
 
   if (m_graphFormat == GOF_BITMAP)
   {
     // run dot to create a bitmap image
-    DotRunner * dotRun = DotManager::instance()->createRunner(absDotName().data(), sigStr.data());
-    dotRun->addJob(Config_getEnum(DOT_IMAGE_FORMAT), absImgName());
-    if (m_generateImageMap) dotRun->addJob(MAP_CMD, absMapName());
+    DotRunner * dotRun = DotManager::instance()->createRunner(absDotName(), sigStr);
+    dotRun->addJob(Config_getEnumAsString(DOT_IMAGE_FORMAT), absImgName(), absDotName(), 1);
+    if (m_generateImageMap) dotRun->addJob(MAP_CMD, absMapName(), absDotName(), 1);
   }
   else if (m_graphFormat == GOF_EPS)
   {
     // run dot to create a .eps image
-    DotRunner *dotRun = DotManager::instance()->createRunner(absDotName().data(), sigStr.data());
+    DotRunner *dotRun = DotManager::instance()->createRunner(absDotName(), sigStr);
     if (Config_getBool(USE_PDFLATEX))
     {
-      dotRun->addJob("pdf",absImgName());
+      dotRun->addJob("pdf",absImgName(),absDotName(),1);
     }
     else
     {
-      dotRun->addJob("ps",absImgName());
+      dotRun->addJob("ps",absImgName(),absDotName(),1);
     }
   }
   return TRUE;
 }
 
-void DotGraph::generateCode(FTextStream &t)
+void DotGraph::generateCode(TextStream &t)
 {
   QCString imgExt = getDotImageExtension();
   if (m_graphFormat==GOF_BITMAP && m_textFormat==EOF_DocBook)
   {
-    t << "<para>" << endl;
-    t << "    <informalfigure>" << endl;
-    t << "        <mediaobject>" << endl;
-    t << "            <imageobject>" << endl;
+    t << "<para>\n";
+    t << "    <informalfigure>\n";
+    t << "        <mediaobject>\n";
+    t << "            <imageobject>\n";
     t << "                <imagedata";
     t << " width=\"50%\" align=\"center\" valign=\"middle\" scalefit=\"0\" fileref=\"" << m_relPath << m_baseName << "." << imgExt << "\">";
-    t << "</imagedata>" << endl;
-    t << "            </imageobject>" << endl;
-    t << "        </mediaobject>" << endl;
-    t << "    </informalfigure>" << endl;
-    t << "</para>" << endl;
+    t << "</imagedata>\n";
+    t << "            </imageobject>\n";
+    t << "        </mediaobject>\n";
+    t << "    </informalfigure>\n";
+    t << "</para>\n";
   }
   else if (m_graphFormat==GOF_BITMAP && m_generateImageMap) // produce HTML to include the image
   {
@@ -233,28 +236,28 @@ void DotGraph::generateCode(FTextStream &t)
         if (m_regenerate)
         {
           DotManager::instance()->
-               createFilePatcher(absImgName().data())->
+               createFilePatcher(absImgName())->
                addSVGConversion(m_relPath,FALSE,QCString(),m_zoomable,m_graphId);
         }
         int mapId = DotManager::instance()->
-               createFilePatcher(m_fileName.data())->
+               createFilePatcher(m_fileName)->
                addSVGObject(m_baseName,absImgName(),m_relPath);
-        t << "<!-- SVG " << mapId << " -->" << endl;
+        t << "<!-- SVG " << mapId << " -->\n";
       }
-      if (!m_noDivTag) t << "</div>" << endl;
+      if (!m_noDivTag) t << "</div>\n";
     }
     else // add link to bitmap file with image map
     {
       if (!m_noDivTag) t << "<div class=\"center\">";
-      t << "<img src=\"" << relImgName() << "\" border=\"0\" usemap=\"#" << getMapLabel() << "\" alt=\"" << getImgAltText() << "\"/>";
+      t << "<img src=\"" << relImgName() << "\" border=\"0\" usemap=\"#" << correctId(getMapLabel()) << "\" alt=\"" << getImgAltText() << "\"/>";
       if (!m_noDivTag) t << "</div>";
-      t << endl;
-      if (m_regenerate || !insertMapFile(t, absMapName(), m_relPath, getMapLabel()))
+      t << "\n";
+      if (m_regenerate || !insertMapFile(t, absMapName(), m_relPath, correctId(getMapLabel())))
       {
         int mapId = DotManager::instance()->
-          createFilePatcher(m_fileName.data())->
+          createFilePatcher(m_fileName)->
           addMap(absMapName(), m_relPath, m_urlOnly, QCString(), getMapLabel());
-        t << "<!-- MAP " << mapId << " -->" << endl;
+        t << "<!-- MAP " << mapId << " -->\n";
       }
     }
   }
@@ -263,17 +266,15 @@ void DotGraph::generateCode(FTextStream &t)
     if (m_regenerate || !DotFilePatcher::writeVecGfxFigure(t,m_baseName,absBaseName()))
     {
       int figId = DotManager::instance()->
-                  createFilePatcher(m_fileName.data())->
+                  createFilePatcher(m_fileName)->
                   addFigure(m_baseName,absBaseName(),FALSE /*TRUE*/);
-      t << endl << "% FIG " << figId << endl;
+      t << "\n% FIG " << figId << "\n";
     }
   }
 }
 
-void DotGraph::writeGraphHeader(FTextStream &t,const QCString &title)
+void DotGraph::writeGraphHeader(TextStream &t,const QCString &title)
 {
-  int fontSize      = Config_getInt(DOT_FONTSIZE);
-  QCString fontName = Config_getString(DOT_FONTNAME);
   t << "digraph ";
   if (title.isEmpty())
   {
@@ -283,28 +284,23 @@ void DotGraph::writeGraphHeader(FTextStream &t,const QCString &title)
   {
     t << "\"" << convertToXML(title) << "\"";
   }
-  t << endl << "{" << endl;
+  t << "\n{\n";
   if (Config_getBool(INTERACTIVE_SVG)) // insert a comment to force regeneration when this
                        // option is toggled
   {
     t << " // INTERACTIVE_SVG=YES\n";
   }
   t << " // LATEX_PDF_SIZE\n"; // write placeholder for LaTeX PDF bounding box size replacement
-  if (Config_getBool(DOT_TRANSPARENT))
-  {
-    t << "  bgcolor=\"transparent\";" << endl;
-  }
-  t << "  edge [fontname=\"" << fontName << "\","
-         "fontsize=\"" << fontSize << "\","
-         "labelfontname=\"" << fontName << "\","
-         "labelfontsize=\"" << fontSize << "\"];\n";
-  t << "  node [fontname=\"" << fontName << "\","
-         "fontsize=\"" << fontSize << "\",shape=record];\n";
+  t << "  bgcolor=\"transparent\";\n";
+  QCString c = Config_getString(DOT_COMMON_ATTR);
+  if (!c.isEmpty()) c += ",";
+  t << "  edge [" << c << Config_getString(DOT_EDGE_ATTR) << "];\n";
+  t << "  node [" << c << Config_getString(DOT_NODE_ATTR) << "];\n";
 }
 
-void DotGraph::writeGraphFooter(FTextStream &t)
+void DotGraph::writeGraphFooter(TextStream &t)
 {
-  t << "}" << endl;
+  t << "}\n";
 }
 
 void DotGraph::computeGraph(DotNode *root,
@@ -314,31 +310,31 @@ void DotGraph::computeGraph(DotNode *root,
                             bool renderParents,
                             bool backArrows,
                             const QCString &title,
-                            QGString &graphStr)
+                            QCString &graphStr)
 {
   //printf("computeMd5Signature\n");
-  QGString buf;
-  FTextStream md5stream(&buf);
+  TextStream md5stream;
   writeGraphHeader(md5stream,title);
   if (!rank.isEmpty())
   {
-    md5stream << "  rankdir=\"" << rank << "\";" << endl;
+    md5stream << "  rankdir=\"" << rank << "\";\n";
   }
   root->clearWriteFlag();
   root->write(md5stream, gt, format, gt!=CallGraph && gt!=Dependency, TRUE, backArrows);
-  if (renderParents && root->parents())
+  if (renderParents)
   {
-    QListIterator<DotNode>  dnli(*root->parents());
-    const DotNode *pn;
-    for (dnli.toFirst();(pn=dnli.current());++dnli)
+    for (const auto &pn : root->parents())
     {
       if (pn->isVisible())
       {
+        const auto &children = pn->children();
+        auto child_it = std::find(children.begin(),children.end(),root);
+        size_t index = child_it - children.begin();
         root->writeArrow(md5stream,                              // stream
             gt,                                                  // graph type
             format,                                              // output format
             pn,                                                  // child node
-            pn->edgeInfo()->at(pn->children()->findRef(root)),   // edge info
+            &pn->edgeInfo()[index],                              // edge info
             FALSE,                                               // topDown?
             backArrows                                           // point back?
           );
@@ -354,6 +350,6 @@ void DotGraph::computeGraph(DotNode *root,
   }
   writeGraphFooter(md5stream);
 
-  graphStr=buf.data();
+  graphStr=md5stream.str();
 }
 
