@@ -22,6 +22,7 @@
 #include "debug.h"
 #include "fileinfo.h"
 #include "dir.h"
+#include "indexlist.h"
 
 QCString PlantumlManager::writePlantUMLSource(const QCString &outDirArg,const QCString &fileName,
                                               const QCString &content,OutputFormat format, const QCString &engine,
@@ -143,7 +144,6 @@ static void runPlantumlContent(const PlantumlManager::FilesMap &plantumlFiles,
   int exitCode;
   QCString plantumlJarPath = Config_getString(PLANTUML_JAR_PATH);
   QCString plantumlConfigFile = Config_getString(PLANTUML_CFG_FILE);
-  QCString dotPath = Config_getString(DOT_PATH);
 
   QCString pumlExe = "java";
   QCString pumlArgs = "";
@@ -174,12 +174,14 @@ static void runPlantumlContent(const PlantumlManager::FilesMap &plantumlFiles,
     pumlArgs += plantumlConfigFile;
     pumlArgs += "\" ";
   }
-  if (Config_getBool(HAVE_DOT) && !dotPath.isEmpty())
+  // the -graphvizdot option expects a relative or absolute path to the dot executable, so
+  // we need to use the unverified DOT_PATH option and check if it points to an existing file.
+  QCString dotPath = Config_getString(DOT_PATH);
+  FileInfo dp(dotPath.str());
+  if (Config_getBool(HAVE_DOT) && dp.exists() && dp.isFile())
   {
     pumlArgs += "-graphvizdot \"";
     pumlArgs += dotPath;
-    pumlArgs += "dot";
-    pumlArgs += Portable::commandExtension();
     pumlArgs += "\" ";
   }
   switch (format)
