@@ -38,6 +38,10 @@ class TranslatorDutch : public Translator
     { return "\\usepackage[dutch]{babel}\n"; }
     QCString trISOLang()
     { return "nl"; }
+    virtual QCString getLanguageString()
+    {
+      return "0x413 Dutch";
+    }
     QCString trRelatedFunctions()
     { return "Gerelateerde functies"; }
     QCString trRelatedSubscript()
@@ -64,7 +68,7 @@ class TranslatorDutch : public Translator
     { return ", inclusief alle overge&euml;rfde members."; }
     QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automatisch gegenereerd door Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" voor "+s;
+      if (!s.isEmpty()) result+=" voor "+s;
       result+=" uit de programmatekst.";
       return result;
     }
@@ -166,13 +170,24 @@ class TranslatorDutch : public Translator
     QCString trModuleDocumentation()
     { return "Module Documentatie"; }
     QCString trClassDocumentation()
-    { return "Klassen Documentatie"; }
+    {
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+      {
+        return "Klassen Documentatie";
+      }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
+      else
+      {
+        return "Klassen Documentatie";
+      }
+    }
     QCString trFileDocumentation()
     { return "Bestand Documentatie"; }
     QCString trExampleDocumentation()
     { return "Documentatie van voorbeelden"; }
-    QCString trPageDocumentation()
-    { return "Documentatie van gerelateerde pagina's"; }
     QCString trReferenceManual()
     { return "Naslagwerk"; }
 
@@ -204,17 +219,15 @@ class TranslatorDutch : public Translator
     { return "Klassen"; }
     QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Gegenereerd op "+date;
-      if (!projName.isEmpty()) result+=(QCString)" voor "+projName;
-      result+=(QCString)" door";
+      QCString result="Gegenereerd op "+date;
+      if (!projName.isEmpty()) result+=" voor "+projName;
+      result+=" door";
       return result;
     }
     QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Klasse diagram voor "+clName;
+      return "Klasse diagram voor "+clName;
     }
-    QCString trForInternalUseOnly()
-    { return "Alleen voor intern gebruik."; }
     QCString trWarning()
     { return "Waarschuwing"; }
     QCString trVersion()
@@ -264,7 +277,7 @@ class TranslatorDutch : public Translator
                                  bool isTemplate)
       // used as the title of the HTML page of a class/struct/union
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isTemplate) result+=" Template";
       switch(compType)
       {
@@ -414,8 +427,8 @@ class TranslatorDutch : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      static bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
-      QCString result=(QCString)"De documentatie voor ";
+      bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
+      QCString result="De documentatie voor ";
       switch(compType)
       {
         case ClassDef::Class:      result+=vhdlOpt?"deze ontwerp eenheid":"deze klasse"; break;
@@ -482,12 +495,12 @@ class TranslatorDutch : public Translator
     /*! this text is put before a collaboration diagram */
     QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Collaboratie diagram voor "+clName+":";
+      return "Collaboratie diagram voor "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Include afhankelijkheidsgraaf voor "+fName+":";
+      return "Include afhankelijkheidsgraaf voor "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     QCString trConstructorDocumentation()
@@ -692,7 +705,7 @@ class TranslatorDutch : public Translator
         "</ul>\n"
         "De pijlen hebben de volgende betekenis:\n"
         "<ul>\n"
-        "<li>Een donkerblauwe pijl visualizeert een public inheritance "
+        "<li>Een blauwe pijl visualizeert een public inheritance "
         "relatie tussen twee klassen.\n"
         "<li>Een donkergroene pijl wordt gebruikt voor protected inheritance.\n"
         "<li>Een donkerrode pijl wordt gebruikt voor private inheritance.\n"
@@ -752,12 +765,7 @@ class TranslatorDutch : public Translator
     /*! Used as the title of a Java package */
     QCString trPackage(const QCString &name)
     {
-      return (QCString)"Package "+name;
-    }
-    /*! Title of the package index page */
-    QCString trPackageList()
-    {
-      return "Package Lijst";
+      return "Package "+name;
     }
     /*! The description of the package index page */
     QCString trPackageListDescription()
@@ -845,7 +853,7 @@ class TranslatorDutch : public Translator
      */
     virtual QCString trClass(bool first_capital, bool singular)
     {
-      QCString result((first_capital ? "Klasse" : "klass"));
+      QCString result((first_capital ? "Klasse" : "klasse"));
       if (!singular)  result+="n";
       return result;
     }
@@ -1008,14 +1016,18 @@ class TranslatorDutch : public Translator
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Package Functies";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Package Members";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statische Package Functies";
     }
@@ -1127,14 +1139,6 @@ class TranslatorDutch : public Translator
     virtual QCString trDirectories()
     { return "Folders"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Deze folder hi&euml;rarchie is min of meer alfabetisch "
-             "gesorteerd:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1254,7 +1258,7 @@ class TranslatorDutch : public Translator
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       switch(compType)
       {
         case ClassDef::Class:      result+=" Module"; break;
@@ -1318,7 +1322,7 @@ class TranslatorDutch : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"De documentatie voor ";
+      QCString result="De documentatie voor ";
       switch(compType)
       {
         case ClassDef::Class:      result+="deze module"; break;
@@ -1370,7 +1374,7 @@ class TranslatorDutch : public Translator
     /*! directory relation for \a name */
     virtual QCString trDirRelation(const QCString &name)
     {
-      return QCString(name)+" Relatie";
+      return name+" Relatie";
     }
 
     /*! Loading message shown when loading search results */
@@ -1407,7 +1411,7 @@ class TranslatorDutch : public Translator
      */
     virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Bestand in "+name;
+      return "Bestand in "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
@@ -1416,7 +1420,7 @@ class TranslatorDutch : public Translator
      */
     virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Includeert bestand in "+name;
+      return "Includeert bestand in "+name;
     }
     virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
                                 int hour,int minutes,int seconds,
@@ -1434,6 +1438,27 @@ class TranslatorDutch : public Translator
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "ma", "di", "wo", "do", "vr", "za", "zo" };
+      static const char *days_full[]    = { "maandag", "dinsdag", "woensdag", "donderdag", "vrijdag", "zaterdag", "zondag" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "jan", "feb", "mrt", "apr", "mei", "jun", "jul", "aug", "sep", "okt", "nov", "dec" };
+      static const char *months_full[]  = { "januari", "februari", "maart", "april", "mei", "juni", "juli", "augustus", "september", "oktober", "november", "december" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "a.m.", "p.m." };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1449,7 +1474,7 @@ class TranslatorDutch : public Translator
 
     /*! Header for the graph showing the directory dependencies */
     virtual QCString trDirDepGraph(const QCString &name)
-    { return QCString("Folder afhankelijkheidsgraaf voor ")+name+":"; }
+    { return "Folder afhankelijkheidsgraaf voor "+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.8.0
@@ -1478,11 +1503,11 @@ class TranslatorDutch : public Translator
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
     virtual QCString trEnumReference(const QCString &name)
-    { return QCString(name)+" Enum Referentie"; }
+    { return name+" Enum Referentie"; }
 
     /*! Used for a section containing inherited members */
     virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
-    { return QCString(members)+" overge&euml;rfd van "+what; }
+    { return members+" overge&euml;rfd van "+what; }
 
     /*! Header of the sections with inherited members specific for the
      *  base class(es)
@@ -1571,14 +1596,14 @@ class TranslatorDutch : public Translator
     /** UNO IDL service page title */
     virtual QCString trServiceReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Service Referentie";
       return result;
     }
     /** UNO IDL singleton page title */
     virtual QCString trSingletonReference(const QCString &sName)
     {
-      QCString result=(QCString)sName;
+      QCString result=sName;
       result+=" Singleton Referentie";
       return result;
     }
@@ -1714,7 +1739,7 @@ class TranslatorDutch : public Translator
       }
     }
     virtual QCString trCustomReference(const QCString &name)
-    { return QCString(name)+" Referentie"; }
+    { return name+" Referentie"; }
 
     /* Slice */
     virtual QCString trConstants()
@@ -1767,7 +1792,7 @@ class TranslatorDutch : public Translator
     { return "Documentatie van exceptions"; }
     virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       if (isLocal) result+=" Lokale";
       switch(compType)
       {
@@ -1837,6 +1862,12 @@ class TranslatorDutch : public Translator
       return "Concept definitie";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.4
+//////////////////////////////////////////////////////////////////////////
+
+    virtual QCString trPackageList()
+    { return "Package Lijst"; }
 };
 
 #endif
