@@ -19,13 +19,15 @@
  *        Ulisses Guedes <uli1958 at hotmail dot com>
  *
  * Notes about this translation:
- *    Since I'm Brazilian, this translation may be odd or even incorect for
+ *    Since I'm Brazilian, this translation may be odd or even incorrect for
  *    Portuguese (from Portugal) speakers. If you find any errors, feel free
  *    to contact me.
  *
  * VERSION HISTORY
  * ---------------
  * History:
+  * 20220525:
+ * 	- Updated to 1.9.4;
  * 20211003:
  *  - Updated to 1.9.3;
  * 20200112:
@@ -104,6 +106,10 @@ class TranslatorPortuguese : public Translator
     {
       return "pt";
     }
+    virtual QCString getLanguageString()
+    {
+      return "0x816 Portuguese(Portugal)";
+    }
 
     // --- Language translation methods -------------------
 
@@ -169,7 +175,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Gerado automaticamente por Doxygen";
-      if (!s.isEmpty()) result+=(QCString)" para "+s;
+      if (!s.isEmpty()) result+=" para "+s;
       result+=" a partir do código fonte.";
       return result;
     }
@@ -409,7 +415,20 @@ class TranslatorPortuguese : public Translator
      *  the documentation of all classes, structs and unions.
      */
     QCString trClassDocumentation()
-    { return "Documentação da classe"; }
+    {
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+      {
+        return "Documentação da estruturas de dados";
+      }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
+      else
+      {
+        return "Documentação da classe";
+      }
+    }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all files.
@@ -423,12 +442,6 @@ class TranslatorPortuguese : public Translator
     QCString trExampleDocumentation()
     { return "Documentação do exemplo"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    QCString trPageDocumentation()
-    { return "Documentação da página"; }
-
     /*! This is used in LaTeX as the title of the document */
     QCString trReferenceManual()
     { return "Manual de referência"; }
@@ -519,22 +532,18 @@ class TranslatorPortuguese : public Translator
      */
     QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Gerado em "+date;
-      if (!projName.isEmpty()) result+=(QCString)" para "+projName;
-      result+=(QCString)" por";
+      QCString result="Gerado em "+date;
+      if (!projName.isEmpty()) result+=" para "+projName;
+      result+=" por";
       return result;
     }
 
     /*! this text is put before a class diagram */
     QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de heranças da classe "+clName;
+      return "Diagrama de heranças da classe "+clName;
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    QCString trForInternalUseOnly()
-    { return "Apenas para uso interno."; }
-
     /*! this text is generated when the \\warning command is used. */
     QCString trWarning()
     { return "Aviso"; }
@@ -622,7 +631,7 @@ class TranslatorPortuguese : public Translator
         default: break;
       }
       if (isTemplate) result+="Template ";
-      result+=(QCString)clName;
+      result+=clName;
       return result;
     }
 
@@ -772,8 +781,8 @@ class TranslatorPortuguese : public Translator
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      static bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
-      QCString result=(QCString)"A documentação para ";
+      bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
+      QCString result="A documentação para ";
       switch(compType)
       {
         case ClassDef::Class:      result+=vhdlOpt?"esta Unidade de Design":"esta classe"; break;
@@ -839,12 +848,12 @@ class TranslatorPortuguese : public Translator
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Diagrama de colaboração para "+clName+":";
+      return "Diagrama de colaboração para "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Diagrama de dependências de inclusão para "+fName+":";
+      return "Diagrama de dependências de inclusão para "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
@@ -1117,12 +1126,7 @@ class TranslatorPortuguese : public Translator
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Pacote "+name;
-    }
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Lista de pacotes";
+      return "Pacote "+name;
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1379,14 +1383,18 @@ class TranslatorPortuguese : public Translator
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Funções do Pacote";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Membros do Pacote";
+    }
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Funções Estáticas do Pacote";
     }
@@ -1498,12 +1506,6 @@ class TranslatorPortuguese : public Translator
     virtual QCString trDirectories()
     { return "Diretórios"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Esta Hierarquia de Diretórios está parcialmente ordenada (ordem alfabética)"; }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
@@ -1639,7 +1641,7 @@ class TranslatorPortuguese : public Translator
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result = (QCString)"Referência ";
+      QCString result = "Referência ";
 
       if (isTemplate) result+="da Template ";
 
@@ -1710,7 +1712,7 @@ class TranslatorPortuguese : public Translator
         bool single)
     { // here s is one of " Module", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para ";
+      QCString result="A documentação para ";
       switch(compType)
       {
         case ClassDef::Class:      result+="este modulo "; break;
@@ -1803,7 +1805,7 @@ class TranslatorPortuguese : public Translator
      */
     virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Ficheiro em "+name;
+      return "Ficheiro em "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
@@ -1812,7 +1814,7 @@ class TranslatorPortuguese : public Translator
      */
     virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Inclui ficheiro em "+name;
+      return "Inclui ficheiro em "+name;
     }
 
     /** Compiles a date string.
@@ -1841,6 +1843,27 @@ class TranslatorPortuguese : public Translator
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full)
+    {
+      static const char *days_short[]   = { "seg", "ter", "qua", "qui", "sex", "sáb", "dom" };
+      static const char *days_full[]    = { "segunda-feira", "terça-feira", "quarta-feira", "quinta-feira", "sexta-feira", "sábado", "domingo" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trMonth(int month, bool first_capital, bool full)
+    {
+      static const char *months_short[] = { "jan", "fev", "mar", "abr", "mai", "jun", "jul", "ago", "set", "out", "nov", "dez" };
+      static const char *months_full[]  = { "janeiro", "fevereiro", "março", "abril", "maio", "junho", "julho", "agosto", "setembro", "outubro", "novembro", "dezembro" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      if (first_capital) return text.mid(0,1).upper()+text.mid(1);
+      else return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "AM", "PM" };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -2005,7 +2028,7 @@ class TranslatorPortuguese : public Translator
     virtual QCString trServiceGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para este serviço "
+      QCString result="A documentação para este serviço "
                                 "foi gerada a partir ";
       if (single) {
         result+="do seguinte ficheiro:";
@@ -2019,7 +2042,7 @@ class TranslatorPortuguese : public Translator
     virtual QCString trSingletonGeneratedFromFiles(bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"A documentação para este singleton "
+      QCString result="A documentação para este singleton "
                                 "foi gerada a partir ";
       if (single) {
         result+="do seguinte ficheiro:";
@@ -2246,7 +2269,7 @@ class TranslatorPortuguese : public Translator
     }
     virtual QCString trCompoundReferenceSlice(const QCString &clName, ClassDef::CompoundType compType, bool isLocal)
     {
-      QCString result=(QCString)"Referência ";
+      QCString result="Referência ";
       switch(compType)
       {
         case ClassDef::Class:      result+="da Classe "; break;
@@ -2334,6 +2357,12 @@ class TranslatorPortuguese : public Translator
 	{
 	  return "Definição de conceito";
 	}
+
+	//////////////////////////////////////////////////////////////////////////
+	// new since 1.9.4
+	//////////////////////////////////////////////////////////////////////////
+    virtual QCString trPackageList()
+    { return "Lista de pacotes"; }
 };
 
 #endif
